<?php
namespace wcf\acp\form;
use wcf\form\AbstractForm;
use wcf\data\didyouknow\DidYouKnowEntry;
use wcf\data\didyouknow\DidYouKnowEntryEditor;
use wcf\data\didyouknow\DidYouKnowEntryAction;
use wcf\data\package\PackageCache;
use wcf\system\exception\SystemException;
use wcf\system\exception\UserInputException;
use wcf\system\html\input\HtmlInputProcessor;
use wcf\system\WCF;
use wcf\util\DateUtil;
use wcf\util\StringUtil;
use wcf\system\language\I18nHandler;

/**
 * Shows the did you know entry add form.
 *
 * @author	Jonathan Frick <defense>
 * @copyright	2009-2012 WBB-World
 * @license	Creative Commons BY-SA 3.0 <http://creativecommons.org/licenses/by-sa/3.0/de/legalcode>
 * @package	de.wbb-world.wcf.didyouknow
 * @subpackage	acp.form
 * @category 	Community Framework
 */
class DidYouKnowEntryAddForm extends AbstractForm {
	/**
	 * @see wcf\page\AbstractPage::$templateName
	 */
	public $templateName = 'didYouKnowAdd';
	
	/**
	 * @see wcf\acp\form\ACPForm::$activeMenuItem
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.didyouknow.add';
	
	/**
	 * @see wcf\page\AbstractPage::$neededPermissions
	 */
	public $neededPermissions = array('admin.didYouKnow.canAddEntry');
	
	/**
	 * message value
	 * @var	string
	 */
	public $message = '';
	
	/**
	 * priority value
	 * @var	float
	 */
	public $priority = 1;
	
	/**
	 * use-own-settings value
	 * @var	boolean
	 */
	public $useOwnSettings = false;
	
	/**
	 * align value
	 * @var	string
	 */
	public $align = 'left';
	
	/**
	 * enable-smilies value
	 * @var	boolean
	 */
	public $enableSmilies = true;
	
	/**
	 * enable-html value
	 * @var	boolean
	 */
	public $enableHtml = true;
	
	/**
	 * enable-bbcode value
	 * @var	boolean
	 */
	public $enableBBCodes = true;
	
	/**
	* @see wcf\page\IPage::readParameters()
	*/
	public function readParameters() {
		parent::readParameters();

		I18nHandler::getInstance()->register('message');
	}


	/**
	 * @see wcf\form\IForm::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		I18nHandler::getInstance()->readValues();
		if (I18nHandler::getInstance()->isPlainValue('message')) $this->message = I18nHandler::getInstance()->getValue('message');
		
		if (isset($_POST['priority'])) $this->priority = StringUtil::trim($_POST['priority']);
		if (isset($_POST['useOwnSettings'])) $this->useOwnSettings = true; else $this->useOwnSettings = false; 
		if (isset($_POST['align'])) $this->align = StringUtil::trim($_POST['align']);
		if (isset($_POST['enableSmilies'])) $this->enableSmilies = true; else $this->enableSmilies = false; 
		if (isset($_POST['enableHtml'])) $this->enableHtml = true; else $this->enableHtml = false; 
		if (isset($_POST['enableBBCodes'])) $this->enableBBCodes = true; else $this->enableBBCodes = false; 
	}
	
	/**
	 * @see wcf\form\IForm::validate()
	 */
	public function validate() {
		parent::validate();
		
		// validate fields
		if (!I18nHandler::getInstance()->validateValue('message')) {
			throw new UserInputException('message');
		}

		// Priority must not be empty
		if (empty($this->priority)) {
			throw new UserInputException('priority');
		}
		
		// Validate priority
		if (!is_numeric($this->priority) || $this->priority > 10 || $this->priority < 1) {
			throw new UserInputException('priority', 'invalid');
		}
	}
	
	/**
	 * @see wcf\form\IForm::save()
	 */
	public function save() {
		parent::save();
		
		// save entry
		$this->objectAction = new DidYouKnowEntryAction(array(), 'create', array('data' => array(
			'message' => $this->message,
			'priority' => $this->priority,
			'useOwnSettings' => (int) $this->useOwnSettings,
			'align' => $this->align,
			'enableSmilies' => (int) $this->enableSmilies,
			'enableHtml' => (int) $this->enableHtml,
			'enableBBCodes' => (int) $this->enableBBCodes
		)));
		$this->objectAction->executeAction();
		
		$returnValues = $this->objectAction->getReturnValues();
		$entryEditor = new DidYouKnowEntryEditor($returnValues['returnValues']);
		
		if (!I18nHandler::getInstance()->isPlainValue('message')) {
			I18nHandler::getInstance()->save('message', 'wcf.didyouknow.message.text'.$entryEditor->dykID, 'wcf.didyouknow.message', PackageCache::getInstance()->getPackageID('de.wbb-world.wcf.didyouknow'));

			// update text
			$entryEditor->update(array(
				'message' => 'wcf.didyouknow.message.text'.$entryEditor->dykID
			));
		}
		
		// call saved event
		$this->saved();
		
		// clear cache
		DidYouKnowEntryEditor::resetCache();
		
		// reset values
		$this->message = $this->align = '';
		$this->isRestricted = false;
		$this->useOwnSettings = false;
		$this->priority = 1;
		
		// show success
		WCF::getTPL()->assign(array(
			'success' => true
		));
	}
	
	/**
	 * @see wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		I18nHandler::getInstance()->assignVariables();
		
		WCF::getTPL()->assign(array(
			'action' => 'add',
			'message' => $this->message,
			'priority' => $this->priority,
			'useOwnSettings' => $this->useOwnSettings,
			'align' => $this->align,
			'enableSmilies' => $this->enableSmilies,
			'enableHtml' => $this->enableHtml,
			'enableBBCodes' => $this->enableBBCodes
		));
	}
}
