<?php
namespace wcf\acp\form;
use wcf\form\AbstractForm;
use wcf\system\WCF;
use wcf\data\package\PackageCache;
use wcf\data\didyouknow\DidYouKnowEntry;
use wcf\data\didyouknow\DidYouKnowEntryEditor;
use wcf\data\didyouknow\DidYouKnowEntryAction;
use wcf\system\language\I18nHandler;
use wcf\system\exception\IllegalLinkException;

/**
 * Shows the did you know entry edit form.
 * 
 * @author	Jonathan Frick <defense>
 * @copyright	2009-2012 WBB-World
 * @license	Creative Commons BY-SA 3.0 <http://creativecommons.org/licenses/by-sa/3.0/de/legalcode>
 * @package	de.wbb-world.wcf.didyouknow
 * @subpackage	acp.form
 * @category 	Community Framework
 */
class DidYouKnowEntryEditForm extends DidYouKnowEntryAddForm {
	/**
	 * @see wcf\acp\form\ACPForm::$activeMenuItem
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.didyouknow.list';
	
	/**
	 * @see wcf\page\AbstractPage::$neededPermissions
	 */
	public $neededPermissions = array('admin.didYouKnow.canAddEntry');
	
	/**
	 * entry id
	 * @var	integer
	 */
	public $dykID = 0;
	
	/**
	 * entry object
	 * @var	wcf\data\didyouknow\DidYouKnowEntry
	 */
	public $entryObj = null;
	
	/**
	 * @see wcf\page\IPage::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['id'])) $this->dykID = intval($_REQUEST['id']);
		$this->entryObj = new DidYouKnowEntry($this->dykID);
		if (!$this->entryObj->dykID) {
			throw new IllegalLinkException();
		}
		
	}
	
	/**
	 * @see wcf\form\IForm::save()
	 */
	public function save() {
		AbstractForm::save();
		
		/* ToDo: Make preview work for I18n texts */
		// show preview
		if (isset($_REQUEST['preview']) && !I18nHandler::getInstance()->hasI18nValues('message')) {
			$preview = \wcf\system\bbcode\MessageParser::getInstance()->parse($this->message, $this->enableSmilies, $this->enableHtml, $this->enableBBCodes, false);
			WCF::getTPL()->assign(array(
				'preview' => $preview
			));
			
			return;
		}
		
		// update dyk entry
		$this->objectAction = new DidYouKnowEntryAction(array($this->dykID), 'update', array('data' => array(
			'message' => $this->message,
			'priority' => $this->priority,
			'useOwnSettings' => (int) $this->useOwnSettings,
			'align' => $this->align,
			'enableSmilies' => (int) $this->enableSmilies,
			'enableHtml' => (int) $this->enableHtml,
			'enableBBCodes' => (int) $this->enableBBCodes
		)));
		$this->objectAction->executeAction();
		
		if (!I18nHandler::getInstance()->isPlainValue('message')) {
			I18nHandler::getInstance()->save('message', 'wcf.didyouknow.message.text'.$this->dykID, 'wcf.didyouknow.message', PackageCache::getInstance()->getPackageID('de.wbb-world.wcf.didyouknow'));

			// update text
			$entryEditor = new DidYouKnowEntryEditor($this->entryObj);
			$entryEditor->update(array(
				'message' => 'wcf.didyouknow.message.text'.$this->dykID
			));
		}

		// clear cache
		DidYouKnowEntryEditor::resetCache();
		
		// call saved event
		$this->saved();
		
		// show success
		WCF::getTPL()->assign(array(
			'success' => true
		));
	}
	
	/**
	 * @see wcf\page\IPage::readData()
	 */
	public function readData() {
		parent::readData();
		
		if (!count($_POST)) {
			I18nHandler::getInstance()->setOptions('message', PackageCache::getInstance()->getPackageID('de.wbb-world.wcf.didyouknow'), 'wcf.didyouknow.message.text'.$this->dykID, 'wcf.didyouknow.message.text\d+');
			$this->message = $this->entryObj->message;
			$this->enableHtml = $this->entryObj->enableHtml;
			$this->align = $this->entryObj->align;
			$this->isRestricted = $this->entryObj->isRestricted;
			$this->useOwnSettings = $this->entryObj->useOwnSettings;
			$this->priority = $this->entryObj->priority;
		}
		
	}
	
	/**
	 * @see wcf\page\IPage::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		$useRequestData = (count($_POST)) ? true : false;
		I18nHandler::getInstance()->assignVariables($useRequestData);
		
		WCF::getTPL()->assign(array(
			'dykID' => $this->dykID,
			'entryObj' => $this->entryObj,
			'action' => 'edit'
		));
	}
}
