<?php
namespace wcf\data\didyouknow;
use wcf\data\AbstractDatabaseObjectAction;
use wcf\system\WCF;
use wcf\data\IToggleAction;
use wcf\data\language\item\LanguageItemAction;
use wcf\system\database\util\PreparedStatementConditionBuilder;
use wcf\system\message\embedded\object\MessageEmbeddedObjectManager;

/**
 * Executes did you know entry-related actions.
 * 
 * @author	Jonathan Frick <defense>
 * @copyright	2009-2012 WBB-World
 * @license	Creative Commons BY-SA 3.0 <http://creativecommons.org/licenses/by-sa/3.0/de/legalcode>
 * @package	de.wbb-world.wcf.didyouknow
 * @subpackage	data.didyouknow
 * @category 	Community Framework
 */
class DidYouKnowEntryAction extends AbstractDatabaseObjectAction implements IToggleAction {
	/**
	 * @see	wcf\data\AbstractDatabaseObjectAction::$className
	 */
	protected $className = 'wcf\data\didyouknow\DidYouKnowEntryEditor';
	
	/**
	 * @see	wcf\data\AbstractDatabaseObjectAction::$permissionsUpdate
	 */
	protected $permissionsUpdate = array('admin.didYouKnow.canAddEntry');
	
	/**
	 * @see	wcf\data\AbstractDatabaseObjectAction::$permissionsDelete
	 */
	protected $permissionsDelete = array('admin.didYouKnow.canDeleteEntry');
	
	/**
	 * @see	wcf\data\AbstractDatabaseObjectAction::$permissionsCreate
	 */
	protected $permissionsCreate = array('admin.didYouKnow.canAddEntry');
	
	/**
	 * @see	wcf\data\IToggleAction::validateToggle()
	 */
	public function validateToggle() {
		parent::validateUpdate();
	}
	
	/**
	 * @see	wcf\data\IToggleAction::toggle()
	 */
	public function toggle() {
		foreach ($this->objects as $entry) {
			$entry->update(array(
				'isDisabled' => $entry->isDisabled ? 0 : 1
			));
		}
	}
	
	/**
	 * Validates permissions and parameters.
	 */
	public function validateImport() {
		parent::validateCreate(); 
	}

	/**
	 * Imports options.
	 */
	public function import() {
		// create data
		call_user_func(array($this->className, 'import'), $this->parameters['data']);
	}
	
	/**
	 * @see wcf\data\AbstractDatabaseObjectAction::delete()
	 */
	public function delete() {
		$count = parent::delete();
		
		if (!empty($this->objects)) {
			// identify i18n entrys
			$languageVariables = array();
			foreach ($this->objects as $object) {
				if (preg_match('~wcf.didyouknow.message.text\d+~', $object->message)) {
					$languageVariables[] = $object->message;
				}
			}
			
			// remove language variables
			if (!empty($languageVariables)) {
				$conditions = new PreparedStatementConditionBuilder();
				$conditions->add("languageItem IN (?)", array($languageVariables));
				
				$sql = "SELECT	languageItemID
					FROM	wcf".WCF_N."_language_item
					".$conditions;
				$statement = WCF::getDB()->prepareStatement($sql);
				$statement->execute($conditions->getParameters());
				$languageItemIDs = array();
				while ($row = $statement->fetchArray()) {
					$languageItemIDs[] = $row['languageItemID'];
				}
				
				$objectAction = new LanguageItemAction($languageItemIDs, 'delete');
				$objectAction->executeAction();
			}
		}
	}
}
