<?php
namespace wcf\data\didyouknow;
use wcf\data\DatabaseObjectEditor;
use wcf\data\IEditableCachedObject;
use wcf\system\language\LanguageFactory;
use wcf\data\language\LanguageEditor;
use wcf\data\language\category\LanguageCategory;
use wcf\system\cache\builder\DidYouKnowCacheBuilder;
use wcf\system\WCF;

/**
 * Provides functions to edit did you know entrys.
 * 
 * @author	Jonathan Frick <defense>
 * @copyright	2009-2012 WBB-World
 * @license	Creative Commons BY-SA 3.0 <http://creativecommons.org/licenses/by-sa/3.0/de/legalcode>
 * @package	de.wbb-world.wcf.didyouknow
 * @subpackage	data.didyouknow
 * @category 	Community Framework
 */
class DidYouKnowEntryEditor extends DatabaseObjectEditor implements IEditableCachedObject  {
	/**
	 * @see	wcf\data\DatabaseObjectDecorator::$baseClass
	 */
	protected static $baseClass = 'wcf\data\didyouknow\DidYouKnowEntry';
	
	/**
	 * Updates the view count.
	 */
	public function updateViewCount() {
		$sql = "UPDATE	".static::getDatabaseTableName()."
			SET	views = views + 1
			WHERE	".static::getDatabaseTableIndexName()." = ?";
		$statement = WCF::getDB()->prepareStatement($sql);
		$statement->execute(array($this->dykID));
	}
	/**
	 * Imports the given entrys.
	 * 
	 * @param 	array		$entrys
	 */
	public static function import(array $entrys) {
		$updateValues = array();
		$languageImport = array();

		// import entrys
		$sql = "INSERT INTO wcf".WCF_N."_didyouknow
					(message, isDisabled, priority, enableSmilies, enableHtml, enableBBCodes)
			VALUES		(?, ?, ?, ?, ?, ?)";
		$statement = WCF::getDB()->prepareStatement($sql);
		foreach ($entrys as $key => $value) {
			// support for i18n-text values
			if (is_array($value['message'])) {
				$languageImport['last'] = $value['message'];
				$value['message'] = '';
			}

			// execute statement
			$statement->execute(array(
				$value['message'], 
				$value['isDisabled'], 
				$value['priority'],
				$value['enableSmilies'], 
				$value['enableHtml'], 
				$value['enableBBCodes']
			));

			// support for i18n-text values
			if (!empty($languageImport['last'])) {
				foreach ($languageImport['last'] as $languageCode => $value) {
					$languageImport[$languageCode]['wcf.didyouknow.message.text'.WCF::getDB()->getInsertID('wcf'.WCF_N.'_didyouknow', 'dykID')] = $value;
				}
				$updateValues[WCF::getDB()->getInsertID('wcf'.WCF_N.'_didyouknow', 'dykID')] = 'wcf.didyouknow.message.text'.WCF::getDB()->getInsertID('wcf'.WCF_N.'_didyouknow', 'dykID');
				unset ($languageImport['last']);
			}
		}

		// import language if necessary 
		if (!empty($languageImport)) {
			// get language category
			$sql = "SELECT	languageCategoryID
				FROM	wcf".WCF_N."_language_category
				WHERE	languageCategory = ?";
			$statement = WCF::getDB()->prepareStatement($sql);
			$statement->execute(array('wcf.didyouknow.message'));
			$row = $statement->fetchArray();
			$languageCategory = new LanguageCategory(null,$row);
		
			foreach ($languageImport as $languageCode => $items) {
				// try to find an existing language with the given language code
				$language = LanguageFactory::getInstance()->getLanguageByCode($languageCode);
			
				// import 
				$languageEditor = new LanguageEditor($language);
				$languageEditor->updateItems ($items, $languageCategory, 1);
			}
		}
		
		// update entrys if necessary
		if (!empty($updateValues)) {
			$sql = "UPDATE wcf".WCF_N."_didyouknow
					SET message = ?
					WHERE dykID = ?";
			$statement = WCF::getDB()->prepareStatement($sql);
			foreach ($updateValues as $dykID => $message) {
				$statement->execute(array($message, $dykID));
			}
		}
		
		LanguageEditor::deleteLanguageFiles(); /* ToDo: Set category here */
		self::resetCache();
	}


	/**
	 * @see	wcf\data\IEditableCachedObject::resetCache()
	 */
	public static function resetCache() {
		DidYouKnowCacheBuilder::getInstance()->reset();
	}
}
